@@ -1,15 +1,47 @@
-import yaml
 from base64 import b64encode
-from collections import OrderedDict
 from hashlib import sha224
 
+import yaml
+from yaml.tokens import (AliasToken, AnchorToken, ScalarToken, FlowMappingStartToken, FlowMappingEndToken, KeyToken,
+                         ValueToken)
+try:
+    from yaml import CSafeLoader as default_loader
+except ImportError:
+    from yaml import SafeLoader as default_loader
+
 def hash_key(key):
     return b64encode(sha224(key.encode() if isinstance(key, str) else key).digest()).decode()
 
-class OrderedLoader(yaml.SafeLoader):
-    pass
 
-def get_loader(use_annotations=False):
+class CustomLoader(yaml.SafeLoader):
+    expand_aliases = False
+
+    def emit_yq_kv(self, key, value, original_token):
+        marks = dict(start_mark=original_token.start_mark, end_mark=original_token.end_mark)
+        self.tokens.append(FlowMappingStartToken(**marks))
+        self.tokens.append(KeyToken(**marks))
+        self.tokens.append(ScalarToken(value=key, plain=True, **marks))
+        self.tokens.append(ValueToken(**marks))
+        self.tokens.append(ScalarToken(value=value, plain=True, **marks))
+        self.tokens.append(FlowMappingEndToken(**marks))
+
+    def fetch_alias(self):
+        if self.expand_aliases:
+            return super().fetch_alias()
+        self.save_possible_simple_key()
+        self.allow_simple_key = False
+        alias_token = self.scan_anchor(AliasToken)
+        self.emit_yq_kv("__yq_alias__", alias_token.value, original_token=alias_token)
+
+    def fetch_anchor(self):
+        if self.expand_aliases:
+            return super().fetch_anchor()
+        self.save_possible_simple_key()
+        self.allow_simple_key = False
+        anchor_token = self.scan_anchor(AnchorToken)  # noqa: F841
+        # self.emit_yq_kv("__yq_anchor__", anchor_token.value, original_token=anchor_token)
+
+def get_loader(use_annotations=False, expand_aliases=True):
     def construct_sequence(loader, node):
         annotations = []
         for i, v_node in enumerate(node.value):
@@ -38,7 +70,7 @@ def get_loader(use_annotations=False):
                 pairs.append(("__yq_style_{}__".format(hash_key(key)), v_node.style))
             elif isinstance(v_node, (yaml.nodes.SequenceNode, yaml.nodes.MappingNode)) and v_node.flow_style is True:
                 pairs.append(("__yq_style_{}__".format(hash_key(key)), "flow"))
-        return OrderedDict(pairs)
+        return dict(pairs)
 
     def parse_unknown_tags(loader, tag_suffix, node):
         if isinstance(node, yaml.nodes.ScalarNode):
@@ -48,7 +80,10 @@ def get_loader(use_annotations=False):
         elif isinstance(node, yaml.nodes.MappingNode):
             return construct_mapping(loader, node)
 
-    OrderedLoader.add_constructor(yaml.resolver.BaseResolver.DEFAULT_MAPPING_TAG, construct_mapping)
-    OrderedLoader.add_constructor(yaml.resolver.BaseResolver.DEFAULT_SEQUENCE_TAG, construct_sequence)
-    OrderedLoader.add_multi_constructor('', parse_unknown_tags)
-    return OrderedLoader
+    loader_class = default_loader if expand_aliases else CustomLoader
+    loader_class.add_constructor(yaml.resolver.BaseResolver.DEFAULT_MAPPING_TAG, construct_mapping)
+    loader_class.add_constructor(yaml.resolver.BaseResolver.DEFAULT_SEQUENCE_TAG, construct_sequence)
+    loader_class.add_multi_constructor('', parse_unknown_tags)
+    loader_class.yaml_constructors.pop("tag:yaml.org,2002:binary", None)
+    loader_class.yaml_constructors.pop("tag:yaml.org,2002:set", None)
+    return loader_class
